@@ -1,6 +1,7 @@
 package jp.sourceforge.acerola3d.a3;
 
 import java.awt.*;
+import java.awt.image.BufferedImage;
 import java.awt.event.KeyListener;
 import javax.vecmath.*;
 import java.io.*;
@@ -430,6 +431,10 @@ public interface A3CanvasInterface {
      * A3Canvasに表示されている内容をPNG画像としてファイルに保存します。
      */
     public void saveImage(File file) throws IOException;
+    /**
+     * A3Canvasに表示されている内容をBufferedImageで返します。
+     */
+    public BufferedImage snapshot();
 //  ----------シーン関係のメソッド---------
     /**
      * シーンを準備します。すでにその番号のシーンが
