@@ -474,6 +474,17 @@ public abstract class A3Object {
         label.setOffset(x,y);
     }
 
+    /**
+     * ラベルを表示する場合のオフセットのX座標を返します。
+     */
+    public void getLabelLoc(double ret[]) {
+        if (label==null) {
+            ret[0]=ret[1]=0.0;
+        } else {
+            label.getOffset(ret);
+        }
+    }
+
     /**
      * 吹き出しをセットします。表示されている吹き出しを
      * 消去したい場合には，引数にnullをわたして下さい．
@@ -500,6 +511,17 @@ public abstract class A3Object {
         balloon.setOffset(d,x,y);
     }
 
+    /**
+     * 吹き出しを表示する場合の向きとオフセットの座標を返します。
+     */
+    public void getBalloonLoc(BalloonDir d,double ret[]) {
+        if (balloon==null) {
+            ret[0]=ret[1]=0.0;
+        } else {
+            balloon.getOffset(d,ret);
+        }
+    }
+
     /**
      * 吹き出しを表示する場合の向きを設定します。
      */
