@@ -1,7 +1,7 @@
 package jp.sourceforge.acerola3d.a3;
 
 import java.awt.*;
-
+import java.awt.image.BufferedImage;
 import javax.media.j3d.*;
 import javax.vecmath.*;
 import java.io.*;
@@ -415,6 +415,10 @@ public class A3Screen implements A3CanvasInterface {
     public void saveImage(File file) throws IOException {
         canvas.saveImage(file);
     }
+    @Override
+    public BufferedImage snapshot() {
+        return canvas.snapshot();
+    }
 //  ----------シーン関係のメソッド---------
     @Override
     public void prepareScene(int s) {
