@@ -1,6 +1,7 @@
 package jp.sourceforge.acerola3d.a3;
 
 import java.awt.*;
+import java.awt.image.BufferedImage;
 import java.awt.event.KeyListener;
 
 import javax.media.j3d.*;
@@ -1362,6 +1363,11 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         //dummy
     }
     @Override
+    public BufferedImage snapshot() {
+        //dummy
+        return null;
+    }
+    @Override
     public void setCameraLookAtPointImmediately(Vector3d lookAt, Vector3d up) {
         //dummy
     }
@@ -1470,6 +1476,22 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
             return;
         emphasizerAA.removeScope((Group)a3.getNode());
     }
+    /**
+     * 引数のjavax.media.j3d.Groupを強調表示にします。
+     */
+    void emphasize(Group g) {
+        if (emphasizerAA.indexOfScope(g)!=-1)
+            return;
+        emphasizerAA.addScope(g);
+    }
+    /**
+     * 引数のjavax.media.j3d.Groupの強調表示をOFFにします。
+     */
+    void unemphasize(Group g) {
+        if (emphasizerAA.indexOfScope(g)==-1)
+            return;
+        emphasizerAA.removeScope(g);
+    }
     /**
      * 引数のA3Objectをポリゴン表示にします。
      */
@@ -1486,4 +1508,20 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
             return;
         polygonizerAA.removeScope((Group)a3.getNode());
     }
+    /**
+     * 引数のjavax.media.j3d.Groupをポリゴン表示にします。
+     */
+    void polygonize(Group g) {
+        if (polygonizerAA.indexOfScope(g)!=-1)
+            return;
+        polygonizerAA.addScope(g);
+    }
+    /**
+     * 引数のjavax.media.j3d.Groupをポリゴン表示をOFFにします。
+     */
+    void unpolygonize(Group g) {
+        if (polygonizerAA.indexOfScope(g)==-1)
+            return;
+        polygonizerAA.removeScope(g);
+    }
 }
