@@ -457,6 +457,30 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
 //        e.encode(image);
 //        out.close();
     }
+
+    @Override
+    public BufferedImage snapshot() {
+        int width = getWidth();
+        int height = getHeight();
+        BufferedImage bImage = new BufferedImage(
+                               width,height,BufferedImage.TYPE_INT_RGB);
+        ImageComponent2D ic2d = new ImageComponent2D(
+                                ImageComponent.FORMAT_RGB,bImage);
+        //DepthComponentFloat dcf = new DepthComponentFloat(width,height);
+        readRaster = new Raster(new Point3f(0.0f,0.0f,0.0f),
+                            Raster.RASTER_COLOR,0,0,width,height,
+                            ic2d,null);
+        check = true;
+        while(check) {
+            try{Thread.sleep(300);}catch(Exception e){;}
+        }
+
+        ImageComponent2D ic = readRaster.getImage();
+        BufferedImage image = ic.getImage();
+
+        return image;
+    }
+
 //  ----------シーン関係のメソッド---------
     @Override
     public void prepareScene(int scene) {
