@@ -3,6 +3,7 @@ package jp.sourceforge.acerola3d.a3;
 import java.awt.event.KeyListener;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
+import java.awt.image.BufferedImage;
 import javax.media.j3d.*;
 import javax.swing.*;
 import javax.vecmath.*;
@@ -379,6 +380,11 @@ public class A3Window extends JFrame implements A3CanvasInterface {
     public void saveImage(File file) throws IOException {
         canvas.saveImage(file);
     }
+
+    @Override
+    public BufferedImage snapshot() {
+        return canvas.snapshot();
+    }
 //  ----------シーン関係のメソッド---------
     @Override
     public void prepareScene(int s) {
