@@ -644,6 +644,30 @@ public class Action3D extends A3Object implements ActionObject {
             super.setLabelLoc(x,y);
         actionBehavior.setLabelLoc(actionNo,x,y);
     }
+    /**
+     * ラベルを表示する場合のオフセットを返します。
+     */
+    public void getLabelLoc(double ret[]) {
+        super.getLabelLoc(ret);
+    }
+    /**
+     * アクションを指定してラベルを表示する場合のオフセットを返します。
+     */
+    public void getLabelLoc(int actionNo,double ret[]) {
+        actionBehavior.getLabelLoc(actionNo,ret);
+    }
+    /**
+     * アクションを指定してラベルを表示する場合のオフセットを返します。
+     */
+    public void getLabelLoc(Serializable action,double ret[]) {
+        int actionNo = 0;
+        if (action instanceof Integer) {
+            actionNo = ((Integer)action).intValue();
+        } else if (action instanceof String) {
+            actionNo = this.getActionNo((String)action);
+        }
+        actionBehavior.getLabelLoc(actionNo,ret);
+    }
     /**
      * 吹き出しをセットします。表示されている吹き出しを
      * 消去したい場合には，引数にnullをわたして下さい．
@@ -703,6 +727,30 @@ public class Action3D extends A3Object implements ActionObject {
         }
         setBalloonLoc(actionNo,d,x,y);
     }
+    /**
+     * 向きを指定して吹き出しを表示する場合のオフセットを返します。
+     */
+    public void getBalloonLoc(A3Object.BalloonDir d,double ret[]) {
+        actionBehavior.getBalloonLoc(d,ret);
+    }
+    /**
+     * アクションと向きを指定して吹き出しを表示する場合のオフセットを返します。
+     */
+    public void getBalloonLoc(int actionNo,A3Object.BalloonDir d,double ret[]) {
+        actionBehavior.getBalloonLoc(actionNo,d,ret);
+    }
+    /**
+     * アクションと向きを指定して吹き出しを表示する場合のオフセットを返します。
+     */
+    public void getBalloonLoc(Serializable action,A3Object.BalloonDir d,double ret[]) {
+        int actionNo = 0;
+        if (action instanceof Integer) {
+            actionNo = ((Integer)action).intValue();
+        } else if (action instanceof String) {
+            actionNo = this.getActionNo((String)action);
+        }
+        actionBehavior.getBalloonLoc(actionNo,d,ret);
+    }
 
     /**
      * 吹き出しを表示する場合の向きを設定します。
