@@ -549,6 +549,10 @@ class ActionBehavior extends Behavior implements Cloneable {
         a3Data.actions[actionNo].labelOffset[0] = x;
         a3Data.actions[actionNo].labelOffset[1] = y;
     }
+    public void getLabelLoc(int actionNo,double ret[]) {
+        ret[0] = a3Data.actions[actionNo].labelOffset[0];
+        ret[1] = a3Data.actions[actionNo].labelOffset[1];
+    }
     public void setBalloonLoc(BalloonDir d,double x,double y) {
         a3Data.actions[actionNo].balloonDirection = d;
         if (d==A3Object.BalloonDir.RIGHT) {
@@ -590,6 +594,24 @@ class ActionBehavior extends Behavior implements Cloneable {
             setBalloonLoc(actionNo,d,x,y);
         }
     }
+    public void getBalloonLoc(BalloonDir d,double ret[]) {
+        getBalloonLoc(actionNo,d,ret);
+    }
+    public void getBalloonLoc(int actionNo,BalloonDir d,double ret[]) {
+        if (d==A3Object.BalloonDir.RIGHT) {
+            ret[0] = a3Data.actions[actionNo].rightBalloonOffset[0];
+            ret[1] = a3Data.actions[actionNo].rightBalloonOffset[1];
+        } else if (d==A3Object.BalloonDir.LEFT) {
+            ret[0] = a3Data.actions[actionNo].leftBalloonOffset[0];
+            ret[1] = a3Data.actions[actionNo].leftBalloonOffset[1];
+        } else if (d==A3Object.BalloonDir.TOP) {
+            ret[0] = a3Data.actions[actionNo].topBalloonOffset[0];
+            ret[1] = a3Data.actions[actionNo].topBalloonOffset[1];
+        } else if (d==A3Object.BalloonDir.BOTTOM) {
+            ret[0] = a3Data.actions[actionNo].bottomBalloonOffset[0];
+            ret[1] = a3Data.actions[actionNo].bottomBalloonOffset[1];
+        }
+    }
     public void setBalloonDir(BalloonDir d) {
         a3Data.actions[actionNo].balloonDirection = d;
     }
