@@ -3,6 +3,7 @@ package jp.sourceforge.acerola3d.a3;
 import java.awt.event.KeyListener;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
+import java.awt.image.BufferedImage;
 import javax.media.j3d.*;
 import javax.swing.*;
 import javax.vecmath.*;
@@ -360,6 +361,11 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
         canvas.saveImage(file);
     }
 
+    @Override
+    public BufferedImage snapshot() {
+        return canvas.snapshot();
+    }
+
     @Override
     public int getFPS() {
         return canvas.getFPS();
