@@ -96,6 +96,8 @@ class Scene implements Component2DContainerInterface {
     }
     @SuppressWarnings("unchecked")
     static void setAppearanceOverrideEnable(Group g) {
+        if (g.isCompiled())
+            return;
         Enumeration e = g.getAllChildren();
         while (e.hasMoreElements()) {
             Object o = e.nextElement();
@@ -103,7 +105,7 @@ class Scene implements Component2DContainerInterface {
                 try {
                     ((Shape3D)o).setAppearanceOverrideEnable(true);
                 } catch(CapabilityNotSetException ee) {
-                    //System.out.println("Scene.setAppearanceOverrideEnable().fail!");
+                    System.out.println("Scene.setAppearanceOverrideEnable().fail!");
                 }
             } else if (o instanceof Group) {
                 setAppearanceOverrideEnable((Group)o);
